//
//  AppDelegate.h
//  ObjViewer
//
//  Created by song on 2013-01-21.
//  Copyright (c) 2013 song. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "ViewGL.h"
#import "ModelGL.h"
#import "Timer.h"
#import "GroupNameList.h"



@interface AppDelegate : NSObject <NSApplicationDelegate>
{
    ModelGL model;  // model component
    Timer timer;    // to measure elapsed time
}


@property (assign) IBOutlet NSWindow *window;
@property (unsafe_unretained) IBOutlet NSPanel *panelAbout;

@property (weak) IBOutlet ViewGL *viewGL;

// buttons
@property (weak) IBOutlet NSButton *buttonLoad;
@property (weak) IBOutlet NSButton *buttonAbout;

@property (weak) IBOutlet NSTabView *tabView;
@property (weak) IBOutlet NSView *tabItemView1;
@property (weak) IBOutlet NSView *tabItemView2;
@property (weak) IBOutlet NSView *tabItemView3;

// progress indicator
@property (weak) IBOutlet NSProgressIndicator *spinnerLoading;


// tab1 controls ==============================
@property (weak) IBOutlet NSButton *checkGrid;
@property (weak) IBOutlet NSButton *checkTextures;
@property (weak) IBOutlet NSButton *checkWireframe;
@property (weak) IBOutlet NSButton *checkBoundingBox;
@property (weak) IBOutlet NSButton *checkDefaultTexture;
@property (weak) IBOutlet NSButton *checkBlackBackground;

@property (weak) IBOutlet NSSlider *sliderAmbient;
@property (weak) IBOutlet NSSlider *sliderDiffuse;
@property (weak) IBOutlet NSSlider *sliderSpecular;
@property (weak) IBOutlet NSTextField *labelAmbient;
@property (weak) IBOutlet NSTextField *labelDiffuse;
@property (weak) IBOutlet NSTextField *labelSpecular;

@property (weak) IBOutlet NSSlider *sliderLightX;
@property (weak) IBOutlet NSSlider *sliderLightY;
@property (weak) IBOutlet NSSlider *sliderLightZ;
@property (weak) IBOutlet NSTextField *labelLightX;
@property (weak) IBOutlet NSTextField *labelLightY;
@property (weak) IBOutlet NSTextField *labelLightZ;

@property (weak) IBOutlet NSComboBox *comboScreenshot;
@property (weak) IBOutlet NSTextField *textScreenshot;

@property (weak) IBOutlet NSButton *buttonUp;
@property (weak) IBOutlet NSButton *buttonDown;
@property (weak) IBOutlet NSButton *buttonLeft;
@property (weak) IBOutlet NSButton *buttonRight;


// tab2 controls ==============================
@property (weak) IBOutlet NSTextField *textObjName;
@property (weak) IBOutlet NSTextField *textMtlName;
@property (weak) IBOutlet NSTextField *textTexName;

@property (weak) IBOutlet NSTextField *textWidth;
@property (weak) IBOutlet NSTextField *textHeight;
@property (weak) IBOutlet NSTextField *textDepth;
@property (weak) IBOutlet NSTextField *labelWidth;
@property (weak) IBOutlet NSTextField *labelHeight;
@property (weak) IBOutlet NSTextField *labelDepth;
@property (weak) IBOutlet NSTextField *textArea;
@property (weak) IBOutlet NSTextField *labelCenter;

@property (weak) IBOutlet NSTextField *textTriangleCount;
@property (weak) IBOutlet NSTextField *textIndexCount;
@property (weak) IBOutlet NSTextField *textVertexCount;
@property (weak) IBOutlet NSTextField *textTexCoordCount;

@property (weak) IBOutlet NSTableView *tableGroups;
@property (weak) IBOutlet GroupNameList *groupNames;


// tab3 =======================================
@property (weak) IBOutlet NSStepper *stepPositionX;
@property (weak) IBOutlet NSStepper *stepPositionY;
@property (weak) IBOutlet NSStepper *stepPositionZ;
@property (weak) IBOutlet NSTextField *textPositionX;
@property (weak) IBOutlet NSTextField *textPositionY;
@property (weak) IBOutlet NSTextField *textPositionZ;

@property (weak) IBOutlet NSStepper *stepRotationX;
@property (weak) IBOutlet NSStepper *stepRotationY;
@property (weak) IBOutlet NSStepper *stepRotationZ;
@property (weak) IBOutlet NSTextField *textRotationX;
@property (weak) IBOutlet NSTextField *textRotationY;
@property (weak) IBOutlet NSTextField *textRotationZ;

@property (weak) IBOutlet NSStepper *stepScaleX;
@property (weak) IBOutlet NSStepper *stepScaleY;
@property (weak) IBOutlet NSStepper *stepScaleZ;
@property (weak) IBOutlet NSTextField *textScaleX;
@property (weak) IBOutlet NSTextField *textScaleY;
@property (weak) IBOutlet NSTextField *textScaleZ;

@property (weak) IBOutlet NSTextField *textSaveObj;


// event handlers
- (IBAction)loadObj:(id)sender;
- (IBAction)showAbout:(id)sender;
- (IBAction)closeAbout:(id)sender;
- (IBAction)handleOption:(id)sender;
- (IBAction)resetMaterial:(id)sender;
- (IBAction)updateMaterial:(NSSlider *)sender;
- (IBAction)resetLight:(id)sender;
- (IBAction)updateLight:(NSSlider *)sender;
- (IBAction)saveScreenshot:(id)sender;
- (IBAction)shiftCamera:(NSButton *)sender;
- (IBAction)resetCamera:(id)sender;
- (IBAction)translateX:(NSStepper *)sender;
- (IBAction)translateY:(NSStepper *)sender;
- (IBAction)translateZ:(NSStepper *)sender;
- (IBAction)rotateX:(NSStepper *)sender;
- (IBAction)rotateY:(NSStepper *)sender;
- (IBAction)rotateZ:(NSStepper *)sender;
- (IBAction)scaleX:(NSStepper *)sender;
- (IBAction)scaleY:(NSStepper *)sender;
- (IBAction)scaleZ:(NSStepper *)sender;
- (IBAction)resetTranslation:(id)sender;
- (IBAction)resetRotation:(id)sender;
- (IBAction)resetScale:(id)sender;
- (IBAction)saveObj:(id)sender;

// fill text of controls
- (void) setDescription;
- (void) clearDescription;

// for tableview entries
- (IBAction)handleTableRowClicked:(id)sender;

// callback for loading OBJ
- (void) callbackObjLoaded;

@end
