//
// WindowMain.mm
// =============
// main window for ObjViewer to handle drag-and-drop file
//
// Created by song on 2022-05-30.
// Copyright © 2022 song. All rights reserved.
//

#import "WindowMain.h"

@implementation WindowMain

///////////////////////////////////////////////////////////////////////////////
- (void)awakeFromNib
{
    [super awakeFromNib];
    // for drag-and-drop
    [self registerForDraggedTypes:[NSArray arrayWithObject:NSFilenamesPboardType]];
    printf("WindowMain: awakeFromNib\n");
}



///////////////////////////////////////////////////////////////////////////////
- (NSDragOperation)draggingEntered:(id<NSDraggingInfo>)sender
{
    // available dragging operations:
    // NSDragOperationNone=0, NSDragOperationCopy=1, NSDragOperationLink=2,
    // NSDragOperationGeneric=4, NSDragOperationPrivate=8, NSDragOperationMove=16,
    // NSDragOperationDelete=32, NSDragOperationEvery
    //printf("draggingEntered\n");
    // make sure src operation allows generic mode (== determined by the dest)
    if(sender.draggingSourceOperationMask & NSDragOperationGeneric)
        return NSDragOperationGeneric;
    else
        return NSDragOperationNone;
}



///////////////////////////////////////////////////////////////////////////////
- (void)draggingExited:(id<NSDraggingInfo>)sender
{
    printf("draggingExited\n");
}



///////////////////////////////////////////////////////////////////////////////
- (BOOL)prepareForDragOperation:(id<NSDraggingInfo>)sender
{
    // return yes to receive performDragOperation
    //printf("prepareForDragOperation\n");
    return YES;
}



///////////////////////////////////////////////////////////////////////////////
- (BOOL)performDragOperation:(id<NSDraggingInfo>)sender
{
    //printf("performDragOperation\n");
    NSPasteboard* pboard = sender.draggingPasteboard;
    
    if([pboard.types containsObject:NSFilenamesPboardType])
    {
        NSArray* files = [pboard propertyListForType:NSFilenamesPboardType];
        //unsigned long numberOfFiles = [files count];
        printf("PATH: %s\n", [files[0] UTF8String]);
    }
    return YES;
}



///////////////////////////////////////////////////////////////////////////////
- (void)concludeDragOperation:(id<NSDraggingInfo>)sender
{
    printf("concludeDragOperation\n");
}

@end
